/**
 * PETALS: PETALS Services Platform Copyright (C) 2009 EBM WebSourcing
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 * 
 * Initial developer(s): EBM WebSourcing
 */
package org.ow2.petals.communication;

import org.objectweb.fractal.fraclet.annotation.annotations.FractalComponent;
import org.objectweb.fractal.fraclet.annotation.annotations.Interface;
import org.objectweb.fractal.fraclet.annotation.annotations.LifeCycle;
import org.objectweb.fractal.fraclet.annotation.annotations.Monolog;
import org.objectweb.fractal.fraclet.annotation.annotations.Provides;
import org.objectweb.fractal.fraclet.annotation.annotations.Requires;
import org.objectweb.fractal.fraclet.annotation.annotations.type.LifeCycleType;
import org.objectweb.util.monolog.api.Logger;
import org.ow2.petals.communication.jmx.JMXService;
import org.ow2.petals.communication.jmx.RemoteJMXServer;
import org.ow2.petals.util.LoggingUtil;

/**
 * JMX based remote checker
 * 
 * @author chamerling - eBM WebSourcing
 * 
 */
@FractalComponent
@Provides(interfaces = @Interface(name = "service", signature = RemoteCheckerClient.class))
public class JMXRemoteCheckerClientImpl implements RemoteCheckerClient {

    private LoggingUtil log;

    @Monolog(name = "logger")
    protected Logger logger;

    @Requires(name = "jmx", signature = org.ow2.petals.communication.jmx.JMXService.class)
    protected JMXService jmxService;

    /**
     * 
     */
    @LifeCycle(on = LifeCycleType.START)
    protected void start() {
        this.log = new LoggingUtil(this.logger);
    }

    /**
     * 
     */
    @LifeCycle(on = LifeCycleType.STOP)
    protected void stop() {

    }

    /**
     * {@inheritDoc}
     */
    public boolean ping(String containerName) {
        boolean result = true;
        try {
            // Retrieve a connection to the JMX server of the container were the
            // component is deployed
            final RemoteJMXServer server = this.jmxService.getRemoteJMXServer(containerName);
            // Ask the component if it is ok to accept the exchange
            final String s = (String) server.invoke(server.getAdminServiceMBeanName(),
                    "getSystemInfo", null, null);
            result = (s != null);
        } catch (final Exception e) {
            this.log.error("Problem in ping service", e);
            result = false;
        }
        return result;
    }

}
