/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: InstallationService.java 154 2006-03-27 15:30:10Z ddesjardins $
 * -------------------------------------------------------------------------
 */
package org.ow2.petals.jbi.management.util;

/**
 * This class gathers the dtd used for the management message
 * 
 * @author ddesjardins - eBMWebsourcing
 * @since 1.0
 */
public class ManagementMessageUtil {

    public static final String TASK_RESULT_FAILED = "FAILED";

    public static final String TASK_RESULT_SUCCESS = "SUCCESS";

    public static final String MESSAGE_TYPE_ERROR = "ERROR";

    public static final String MESSAGE_TYPE_WARNING = "WARNING";

    public static final String MESSAGE_TYPE_INFO = "INFO";

    private static final String XMLNS = "http://java.sun.com/xml/ns/jbi/management-message";

    private static final String TASK_RESULT_DETAILS = "task-result-details";

    private static final String TASK_ID = "task-id";

    private static final String TASK_RESULT = "task-result";

    private static final String MESSAGE_TYPE = "message-type";

    private static final String EXCEPTION_INFO = "exception-info";

    private static final String NESTING_LEVEL = "nesting-level";

    private static final String MSG_LOC_INFO = "msg-loc-info";

    private static final String LOC_TOKEN = "loc-token";

    private static final String LOC_MESSAGE = "loc-message";

    private static final String LOC_PARAM = "loc-param";

    private static final String STACK_TRACE = "stack-trace";

    private static final String COMPONENT_TASK_RESULT = "component-task-result";

    private static final String COMPONENT_TASK_RESULT_DETAILS = "component-task-result-details";

    private static final String COMPONENT_NAME = "component-name";

    /**
     * Return a component task result xml
     * 
     * @param componentName
     *            component name
     * @param taskId
     *            id of the task
     * @param taskResult
     *            result of the task
     * @return xml string
     */
    public static String getComponentTaskResult(String componentName,
            String taskId, String taskResult) {
        return ManagementMessageUtil.getComponentTaskResult(componentName,
                taskId, taskResult, null, null, null, null, null, null, null);
    }

    /**
     * Return a component task result xml
     * 
     * @param componentName
     *            component name
     * @param taskId
     *            id of the task
     * @param taskResult
     *            result of the task
     * @param messageType
     *            type of message
     * @param nestingLevel
     *            nesting level of the exception
     * @param exceptionMessage
     *            message of the exception
     * @param exceptionMessageParams
     *            list of the param for the exception message
     * @param stackStrace
     *            stacktrace
     * @return xml string
     */
    public static String getComponentTaskResult(String componentName,
            String taskId, String taskResult, String messageType,
            String nestingLevel, String exceptionMessage,
            String[] exceptionMessageParams, String stackStrace) {
        return getComponentTaskResult(componentName, taskId, taskResult,
                messageType, null, null, nestingLevel, exceptionMessage,
                exceptionMessageParams, stackStrace);
    }

    /**
     * Return a component task result xml
     * 
     * @param componentName
     *            component name
     * @param taskId
     *            id of the task
     * @param taskResult
     *            result of the task
     * @param messageType
     *            type of message
     * @param message
     *            message
     * @param messageParams
     *            list of param for the message
     * @return xml string
     */
    public static String getComponentTaskResult(String componentName,
            String taskId, String taskResult, String messageType,
            String message, String[] messageParams) {
        return getComponentTaskResult(componentName, taskId, taskResult,
                messageType, message, messageParams, null, null, null, null);
    }

    /**
     * Return a component task result xml
     * 
     * @param componentName
     *            component name
     * @param taskId
     *            id of the task
     * @param taskResult
     *            result of the task
     * @param messageType
     *            type of message
     * @param message
     *            message
     * @param messageParams
     *            list of param for the message
     * @param nestingLevel
     *            nesting level of the exception
     * @param exceptionMessage
     *            message of the exception
     * @param exceptionMessageParams
     *            list of the param for the exception message
     * @param stackStrace
     *            stacktrace
     * @return xml string
     */
    public static String getComponentTaskResult(String componentName,
            String taskId, String taskResult, String messageType,
            String message, String[] messageParams, String nestingLevel,
            String exceptionMessage, String[] exceptionMessageParams,
            String stackStrace) {
        StringBuffer xmlInput = new StringBuffer();
        xmlInput.append("\t\t<" + ManagementMessageUtil.COMPONENT_TASK_RESULT
                + ">\n");
        xmlInput.append("\t\t\t<" + ManagementMessageUtil.COMPONENT_NAME + ">"
                + componentName + "</" + ManagementMessageUtil.COMPONENT_NAME
                + ">\n");
        xmlInput.append("\t\t\t<"
                + ManagementMessageUtil.COMPONENT_TASK_RESULT_DETAILS
                + " xmlns='" + ManagementMessageUtil.XMLNS + "'>\n");
        xmlInput.append("\t\t\t\t<" + ManagementMessageUtil.TASK_RESULT_DETAILS
                + ">\n");
        xmlInput.append("\t\t\t\t\t<" + ManagementMessageUtil.TASK_ID + ">"
                + taskId + "</" + ManagementMessageUtil.TASK_ID + ">\n");
        xmlInput
                .append("\t\t\t\t\t<" + ManagementMessageUtil.TASK_RESULT + ">"
                        + taskResult + "</" + ManagementMessageUtil.TASK_RESULT
                        + ">\n");
        if (messageType != null) {
            xmlInput.append("\t\t\t\t\t<" + ManagementMessageUtil.MESSAGE_TYPE
                    + ">" + messageType + "</"
                    + ManagementMessageUtil.MESSAGE_TYPE + ">\n");
            if (message != null) {
                xmlInput.append("\t\t\t\t\t<"
                        + ManagementMessageUtil.MSG_LOC_INFO + ">\n");
                // TODO change token with a key message for looking up localized
                // text
                // for the message
                xmlInput.append("\t\t\t\t\t\t<"
                        + ManagementMessageUtil.LOC_TOKEN + ">jbimsg</"
                        + ManagementMessageUtil.LOC_TOKEN + ">\n");
                xmlInput.append("\t\t\t\t\t\t<"
                        + ManagementMessageUtil.LOC_MESSAGE + ">" + message
                        + "</" + ManagementMessageUtil.LOC_MESSAGE + ">\n");
                for (String string : messageParams) {
                    xmlInput.append("\t\t\t\t\t\t<"
                            + ManagementMessageUtil.LOC_PARAM + ">" + string
                            + "</" + ManagementMessageUtil.LOC_PARAM + ">\n");
                }
                xmlInput.append("\t\t\t\t\t</"
                        + ManagementMessageUtil.MSG_LOC_INFO + ">\n");
            }
            if (exceptionMessage != null) {
                xmlInput.append("\t\t\t\t\t<"
                        + ManagementMessageUtil.EXCEPTION_INFO + ">\n");
                xmlInput.append("\t\t\t\t\t\t<"
                        + ManagementMessageUtil.NESTING_LEVEL + ">"
                        + nestingLevel + "</"
                        + ManagementMessageUtil.NESTING_LEVEL + ">\n");
                xmlInput.append("\t\t\t\t\t\t<"
                        + ManagementMessageUtil.MSG_LOC_INFO + ">\n");
                // TODO change token with a key message for looking up localized
                // text
                // for the message
                xmlInput.append("\t\t\t\t\t\t\t<"
                        + ManagementMessageUtil.LOC_TOKEN + ">jbimsg</"
                        + ManagementMessageUtil.LOC_TOKEN + ">\n");
                xmlInput.append("\t\t\t\t\t\t\t<"
                        + ManagementMessageUtil.LOC_MESSAGE + ">"
                        + exceptionMessage + "</"
                        + ManagementMessageUtil.LOC_MESSAGE + ">\n");
                for (String string : exceptionMessageParams) {
                    xmlInput.append("\t\t\t\t\t\t\t<"
                            + ManagementMessageUtil.LOC_PARAM + ">" + string
                            + "</" + ManagementMessageUtil.LOC_PARAM + ">\n");
                }
                xmlInput.append("\t\t\t\t\t\t</"
                        + ManagementMessageUtil.MSG_LOC_INFO + ">\n");
                if (stackStrace != null) {
                    xmlInput.append("\t\t\t\t\t\t<"
                            + ManagementMessageUtil.STACK_TRACE + ">"
                            + stackStrace + "</"
                            + ManagementMessageUtil.STACK_TRACE + ">\n");
                }
                xmlInput.append("\t\t\t\t</"
                        + ManagementMessageUtil.EXCEPTION_INFO + ">\n");
            }
        }
        xmlInput.append("\t\t\t\t</"
                + ManagementMessageUtil.TASK_RESULT_DETAILS + ">\n");
        xmlInput.append("\t\t\t</"
                + ManagementMessageUtil.COMPONENT_TASK_RESULT_DETAILS + ">\n");
        xmlInput.append("\t\t</" + ManagementMessageUtil.COMPONENT_TASK_RESULT
                + ">\n");
        return xmlInput.toString();
    }

}
